/*
Copyright (C) 2005-2009 Niels Ott

Licensed under the Apache License, Version 2.0 (the "License"); you may not use 
this file except in compliance with the License. You may obtain a copy of the 
License at 
     http://www.apache.org/licenses/LICENSE-2.0 
Unless required by applicable law or agreed to in writing, software distributed 
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR 
CONDITIONS OF ANY KIND, either express or implied. See the License for the specific
language governing permissions and limitations under the License.
 */

package de.drni.bananasplit.affix;

import de.linuxusers.levenshtein.simple.Levenshtein;

/**
A simple class holding an affix
that exists of an part that's added to a word
and a part that's taken away. This is used for some kind
of stemming, or rather: "Deflection" and removal of bounding morphemes.
(Related to Langer(1998))
@author <a href="http://www.drni.de/niels/">Niels Ott</a>
@version $Id: Affix.java 37 2009-02-05 15:26:03Z niels $
*/
public class Affix {

private String add;
private String del;
private float editDistance;

	/**
	Constructor.
	@param Add the affix you want to add.
	@param Del the presumed existing affix to be taken away. 
	*/
	public Affix(String Del, String Add) {
		add = Add;
		del = Del;
		Levenshtein lev = new Levenshtein();
		editDistance = lev.getStringDistance(add, del); 
	}

	/**
	Alternative constructor producing an empty affix.
	*/
	public Affix() {
		this("","");
	}
	
	
	/**
	@return the affix that shall be deleted from the existing word.
	*/
	public String getDel() {
		return del;
	}

	/**
	@return the affix that shall be added to the "corrected" word.
	*/
	public String getAdd() {
		return add;
	}

	/**
	@return the edit distance of this affix:
		How many characters need to be changed
		in general when this affix is applied.
	*/
	public float getEditDistance() {
		return editDistance;
	}

	/**
	@return the length change if this affix is applied, may be a negative number.
	*/
	public int getLengthChange() {
		return getDel().length() - getAdd().length();
	}

	
	/**
	@return the affix as "-del+add" string, empty parts as Ø
	*/
	public String toString() {
		
		String padd = add;
		String pdel = del;
		String empty = "\u00d8";
		
		if ( padd.compareTo("") == 0 ) {
			padd = empty;
		}
		
		if ( pdel.compareTo("") == 0 ) {
			pdel = empty;
		}
		
		
		return "-" + pdel + "+" + padd ;
	}


}
