/*
Copyright (C) 2005-2009 Niels Ott

Licensed under the Apache License, Version 2.0 (the "License"); you may not use 
this file except in compliance with the License. You may obtain a copy of the 
License at 
     http://www.apache.org/licenses/LICENSE-2.0 
Unless required by applicable law or agreed to in writing, software distributed 
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR 
CONDITIONS OF ANY KIND, either express or implied. See the License for the specific
language governing permissions and limitations under the License.
 */
package de.drni.bananasplit.affix;

import java.util.Iterator;
import java.util.Vector;

/**
A  class holding bounding suffixes for German
@author <a href="http://www.drni.de/niels/">Niels Ott</a>
@version $Id: BoundingSuffixCollection.java 37 2009-02-05 15:26:03Z niels $
*/
public class BoundingSuffixCollection implements Iterable<Affix> {

	private Vector<Affix> AffixList;

	/*
	Constructor
	*/
	public BoundingSuffixCollection() {
	
		// Important bounding suffixes according to Langer(1998)
		// (Excluding Umlautung)
		//
		// sorted longest match of suffix first
		// with some additional sorting after experiments
		// Some additional ones added by Niels
		
		// Additional remark: The current implementation makes use
		// of minimum edit distance, so the sorting is irrelevant
	
	
		AffixList = new Vector<Affix>();

		AffixList.add(new Affix(
			"","n"));
		AffixList.add(new Affix(
			"",""));
		AffixList.add(new Affix(
			"","ien"));
		AffixList.add(new Affix(
			"","nen"));
		AffixList.add(new Affix(
			"us","en"));
		AffixList.add(new Affix(
			"um","en"));
		AffixList.add(new Affix(
			"on","en"));
		AffixList.add(new Affix(
			"a","en"));
		AffixList.add(new Affix(
			"e",""));
		AffixList.add(new Affix(
			"","en"));
		AffixList.add(new Affix(
			"","es"));
		AffixList.add(new Affix(
			"","er"));
		AffixList.add(new Affix(
			"um","a"));
		AffixList.add(new Affix(
			"","e"));
		AffixList.add(new Affix(
			"en",""));
		AffixList.add(new Affix(
			"on","a"));
		AffixList.add(new Affix(
			"e","i"));
		AffixList.add(new Affix(
			"e",""));
		AffixList.add(new Affix(
			"","s"));
		AffixList.add(new Affix(
			"n",""));
		AffixList.add(new Affix(
			"","-"));
	}
	
	public Iterator<Affix> iterator() {
		return AffixList.iterator();
	}	
	

}
