/*
Copyright (C) 2005-2009 Niels Ott

Licensed under the Apache License, Version 2.0 (the "License"); you may not use 
this file except in compliance with the License. You may obtain a copy of the 
License at 
     http://www.apache.org/licenses/LICENSE-2.0 
Unless required by applicable law or agreed to in writing, software distributed 
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR 
CONDITIONS OF ANY KIND, either express or implied. See the License for the specific
language governing permissions and limitations under the License.
 */

package de.drni.bananasplit.omat;

import java.util.Iterator;

import de.drni.bananasplit.affix.Affix;

/**
A class that restores base forms of words which have
suffered from some kind of infixational inflection.
(Related to Langer, 1998).
@author <a href="http://www.drni.de/niels/">Niels Ott</a>
@version $Id: InfixOMat.java 37 2009-02-05 15:26:03Z niels $
*/
public class InfixOMat implements AffixOMat {


private String myWord;
private Affix appliedInfix;
private Iterator<Affix> myInfixesIterator;
private Iterable<Affix> myInfixes;

	/**
	Constructor.
	@param infx anything Iterable holding Affixes that can be applied by this Omat. 
	The affixes are of course supposed to be infixes. 
	*/
	public InfixOMat(Iterable<Affix> infx) {
	
		// operate on lowercase only, reset position
		myInfixes = infx;
		init(null);
		
		
	}
	
	/**
		Initialize the SuffoxOMat with a new word to used.
		Resets everything.
		@param word The new word to use from now on;
	*/	
	public void init(String word) {
	
		appliedInfix = null;
		myWord = word;
		myInfixesIterator = myInfixes.iterator();
	}
	

	/**
	Takes the word that "suffered" from a affixation
	and finds the suggested base form by applying the next appropriate affixation rule
	@return the suggested base form of the word or null
		if end of list reached or no results.
	*/
	public String applyNextAffix() {
	
		// if empty (no init() run)
		if (myWord == null) {
			return null;
		}

		// end reached?!		
		if ( ! myInfixesIterator.hasNext() ) {
			return null;
		}
		
		// get the next suffix to work on;	
		Affix infix = myInfixesIterator.next();
				
		String word = myWord;
		
		// there is no String.replaceLast() so go the long way
		int pos = word.lastIndexOf(infix.getAdd());
		
		// not found? go recursive
		if (pos == -1) {
			return applyNextAffix();
		}
		
		// now seems to work so replace it
		word = word.substring(0, pos) +
		       infix.getDel() + 
		       word.substring(pos + infix.getDel().length(),
		       word.length()) ;	
		
		

		appliedInfix = infix;		
		
		return word;
	
	}
	
	/**
	Gives you the infix applied in the last applyNextAffix()
	@return the infix applied in the last applyNextAffix()
		or null if the end was reached already or no infix could be applied.
	*/
	public Affix lastAppliedAffix() {
	
		return appliedInfix;
	
	}

}
