/*
Copyright (C) 2005-2009 Niels Ott

Licensed under the Apache License, Version 2.0 (the "License"); you may not use 
this file except in compliance with the License. You may obtain a copy of the 
License at 
     http://www.apache.org/licenses/LICENSE-2.0 
Unless required by applicable law or agreed to in writing, software distributed 
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR 
CONDITIONS OF ANY KIND, either express or implied. See the License for the specific
language governing permissions and limitations under the License.
 */
package de.drni.bananasplit.simpledict;

/**
 * A class holding a dictionary entry
 * @author <a href="http://www.drni.de/niels/">Niels Ott</a>
 * @version $Id:SimpleDictEntry.java 9 2006-11-22 14:10:50Z niels $
 */
public class SimpleDictEntry {
	
	private String myWord;
	private String myPOS;

	/**
	 * Create a dictionary entry without POS.
	 * @param word the word contained in the entry
	 */
	public SimpleDictEntry(String word) {
		this(word, null);
	}

	/**
	 * Create a dictionary entry with POS
	 * @param word the word contained in the entry.
	 * @param pos the part-of-speach contained in the entry.
	 */
	public SimpleDictEntry(String word, String pos) {
		myWord = word;
		myPOS = pos;
	}
	
	/**
	 * @return the word in the dictionary entry
	 */
	public String getWord() {
		return myWord;
	}
	
	/**
	 * Quite obviously the plain word in the dictionary
	 */
	public String toString() {
		return getWord();
	}
	
	/**
	 * @return The part of speech  (POS) of this entry - may return null if there is none
	 */
	public String getPartOfSpeech() {
		return myPOS;
	}

}
