/*
Copyright (C) 2005-2009 Niels Ott

Licensed under the Apache License, Version 2.0 (the "License"); you may not use 
this file except in compliance with the License. You may obtain a copy of the 
License at 
     http://www.apache.org/licenses/LICENSE-2.0 
Unless required by applicable law or agreed to in writing, software distributed 
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR 
CONDITIONS OF ANY KIND, either express or implied. See the License for the specific
language governing permissions and limitations under the License.
 */
package de.drni.bananasplit.testers;

import java.io.BufferedReader;
import java.io.File;
import java.io.InputStreamReader;

import de.drni.bananasplit.BananaSplit;
import de.drni.bananasplit.simpledict.SimpleDictionaryInterface;
import de.drni.bananasplit.xmldict.XmlDictionary;



/**
 * Tester for the compound splitter/Standalone application compound 
 * splitter using a vertical dictionary file
 * @author <a href="http://www.drni.de/niels/">Niels Ott</a>
 * @version $Id: BananaSplitTester.java 39 2009-02-05 15:37:39Z niels $
 */
public class BananaSplitTester {
	/**
	A main method for testing the thing.
	*/
	public static void main(String[] Args) throws Exception {
	
		// is the path to the dictionary specified?
		if ( Args.length != 1 ) {
			throw(new Exception("Please specify path to XML " +
					"dictionary file as command line argument!"));
		}
		String dictPath = Args[0];

	
		System.err.println(" -- BananaSplit Compound Splitter: Startup -- ");

		System.err.println("Loading XML dictionary from " + dictPath);

		SimpleDictionaryInterface myDict = null;
		try {
			myDict = new XmlDictionary(new File(dictPath), true);

		} catch(Exception e) {
			System.err.println("ERROR! Could not load dictionary from '" +
			dictPath + "', Aborting. Stack Trace:");
	    		e.printStackTrace();
	    	System.exit(1);	
		}

		
		// create a splitter with the dictionary object 		
		BananaSplit splitter = new BananaSplit(myDict);
		
		System.err.println("-- Ready to rumble, type compounds one on a line! (Empty line -> Exit) --");
		
		// NOW HERE THE SPLITTING STUFF....
	
		// read from stdin until empty line occurs... the JavaFun of NormalIO - URKS
		BufferedReader myIN = new BufferedReader(new InputStreamReader(System.in));
		String line = null;
  		while ( ( (line = myIN.readLine()) != null ) && ( line.trim().compareTo("") != 0 )  ) {
		
			// lines starting with # are comments
			if ( line.charAt(0) != '#' ) {
			
				// now for each input line take it as a 
				// compound and feed ot to the splitter
				
		  		// DO SPLIT IT!
				splitter.splitCompound(line.trim());
				
				// OUTPUT...
				System.out.println(splitter);
				// even more output
				System.out.println("# Word stem: " + splitter.getCompound().getLemma());
				System.out.println("");
				
			}	
		}


	} // end of main
}